import mock
import os
import shutil
import tempfile
import unittest
import pkg_resources

from charmhelpers.contrib.cloudfoundry.install import install

FILES_DIR = pkg_resources.resource_filename(__name__, 'files')


class TestInstall(unittest.TestCase):
    def setUp(self):
        self.testdir = tempfile.mkdtemp()

    def tearDown(self):
        shutil.rmtree(self.testdir)

    def test_install_no_src(self):
        self.assertRaises(OSError, install, 'missing', '/tmp')

    @mock.patch('subprocess.check_call')
    def test_install_use_sudo(self, mcall):
        src = os.path.join(FILES_DIR, 'test.conf')
        dest = os.path.join(self.testdir, 'bar')
        install(src, dest, {'owner': 'root'}, sudo=True)
        self.assertEqual(mcall.mock_calls[0],
                         mock.call(['sudo', 'install', '-m', '400',
                                    '-o', 'root', src, dest]))

    @mock.patch('subprocess.check_call')
    def test_install_create_dir(self, mcall):
        src = os.path.join(FILES_DIR, 'test.conf')
        dest = os.path.join(self.testdir, '1/2/3/file')
        install(src, dest)
        self.assertEqual(mcall.call_args,
                         mock.call(['install', '-D', '-m', '400',
                                    src, dest]))

    def test_install_missing_file(self):
        self.assertRaises(OSError, install,
                          'files/missing.conf', self.testdir)


if __name__ == '__main__':
    unittest.main()
